@@ -6,7 +6,7 @@ function(mvrdcvobj,optcomp,y,X,method="simpls",complete=TRUE, ...)
 #
 
 dat=list(y=y,X=as.matrix(X))
-SEP.dcv=apply(drop(mvrdcvobj$pred-y),2,sd)
+SEP.dcv=apply(drop(mvrdcvobj$pred-drop(y)),2,sd)
 matplot(t(SEP.dcv),type="l",lty=1,col=gray(0.6),
   xlab="Number of components",ylab="SEP",cex.lab=1.2,...)
 
@@ -18,7 +18,7 @@ else {
   ncomp <- optcomp
 }
 mvr.cv=mvr(y~X,ncomp=ncomp,data=dat,method=method,validation="CV")
-mvr.res=(drop(mvr.cv$vali$pred)-y)
+mvr.res=(drop(mvr.cv$vali$pred)-drop(y))
 mvr.SEP=apply(mvr.res,2,sd)
 lines(mvr.SEP,col=1,lwd=2)
 
